@@ -2324,11 +2324,11 @@ void qh_option(qhT* qh, const char* option, int* i, realT* r) {
   char buf[200];
   int len, maxlen;
 
-  sprintf(buf, "  %s", option);
+  snprintf(buf, sizeof(buf), "  %s", option);
   if(i)
-    sprintf(buf + strlen(buf), " %d", *i);
+    snprintf(buf + strlen(buf), sizeof(buf), " %d", *i);
   if(r)
-    sprintf(buf + strlen(buf), " %2.2g", *r);
+    snprintf(buf + strlen(buf), sizeof(buf), " %2.2g", *r);
   len = (int)strlen(buf); /* WARN64 */
   qh->qhull_optionlen += len;
   maxlen = sizeof(qh->qhull_options) - len - 1;
